import numpy as np

from grid_env import GridEnvironment

if __name__ == '__main__':

    '''
    The code below demonstrates how to create a GridEnvironment object that represents the robot localization problem.
    '''

    # Specify width and height, in cells
    width = 16
    height = 4

    # Define which cell coordinates correspond to empty squares in which the robot can be
    empty_cell_coords = [[0,0],[0,1],[0,2],[0,3],[0,5],[0,6],[0,7],[0,8],[0,9],[0,11],[0,12],[0,13],[0,15],
                   [1,2],[1,3],[1,5],[1,8],[1,10],[1,12],
                   [2,1],[2,2],[2,3],[2,5],[2,8],[2,9],[2,10],[2,11],[2,12],[2,15],
                   [3,0],[3,1],[3,3],[3,4],[3,5],[3,7],[3,8],[3,9],[3,10],[3,12],[3,13],[3,14],[3,15]]
    n_empty_cells = len(empty_cell_coords)

    # Set the robot's initial location
    init_cell = np.random.randint(n_empty_cells)

    # Set the robot's sensor error rate
    epsilon = 0.2

    # Initialize the environment.
    env = GridEnvironment(width, height, empty_cell_coords, init_cell, epsilon)
    p = env.trans_probs     # Access the environment's transition matrices (we only have 1 matrix since we have 1 possible action)
    o = env.obs_probs       # Access the environment's observation probability matrix

    # Visualize the robot's current location
    env.visualize_state()

    # Visualize the robot's localization belief (a probability distribution over all states)
    belief = np.random.random((n_empty_cells,))     # Get some random numbers in [0,1]
    belief = (belief / np.sum(belief)).tolist()     # Normalize the belief to make it a valid probability distribution
    env.visualize_belief(belief)